Django又拍云存储插件
=========================

**django-upyun** 为Django提供又拍云的接口.


Features
========

- Django file storage for UpYun
- Django static file storage for UpYun
- Works in Python 3.6

安装
============

* Install

开发版本：
.. code-block:: bash

    $ pip install git+https://gitee.com/enlangs/django-upyun-storage.git


正式版本：
.. code-block:: bash
    $ pip install django-upyun


- Add ``'django_upyun'`` to your ``INSTALLED_APPS`` setting
- Set your ``DEFAULT_FILE_STORAGE`` setting to ``"django_upyun.backends.UpYunMediaStorage"``
- Set your ``STATICFILES_STORAGE`` setting to ``"django_upyun.backends.UpYunStaticStorage"``
- Configure your UpYun Storage settings (Refer below).

Use the following settings for file storage.

.. code-block:: bash

    # 配置静态文件；
    STATICFILES_STORAGE = 'django-upyun.backends.UpYunStaticStorage'

    # 配置上传文件使用UpYun存储，如：ImageField、FileField
    DEFAULT_FILE_STORAGE = 'django-upyun.backends.UpYunMediaStorage'

认证设置
=======================

下面的三个设置用来登录upyun服务器

.. code-block:: bash

    # 服务
    UPY_SERVICE = <Your Service>

    # 用户名
    UPY_USERNAME = <Your username>

    # 密码
    UPY_PASSWORD = <Your password>

存储设置
=======================

使用的文件地址。

.. code-block:: bash

    service_url = <地址，支持CDN>

重名文件覆盖设置
====================

针对重名文件的处理方式，如果为True，表示覆盖；为False表示文件名称+时间戳

.. code-block:: bash

    UPY_NEED_COVERAGE = False


File storage settings
=====================

多媒体默认存储设置

.. code-block:: bash

    # 文件默认存储的文件夹
    MEDIA_URL = '/media/'
    

文件存储格式设置
===========================

设置上传后的文件存储到数据库中使用何种方式，为False表示存储为xxx.png

.. code-block:: bash

    UPY_SAVE_FULL_URL = <True/False>


Staticfiles storage settings
============================

静态默认存储设置

.. code-block:: bash

    # The default location for your static files
    STATIC_URL = '/static/'

staticfiles provides command 'collectstatic'. Run following command to collect all sub-folder 'static' of each app
and upload to STATIC_URL.

.. code-block:: bash

    $ python manage.py collectstatic


Testing
=======

需要如下三个配置，like linux系列可以使用环境变量设置。

.. code-block:: bash

    $ export UPY_SERVICE=<service>
    $ export UPY_USERNAME=<username>
    $ export UPY_PASSWORD=<password>

Support and announcements
=========================

Downloads and bug tracking can be found at the `main project website <https://gitee.com/enlangs/django-upyun-storage/issues>`_.

